package saccubus;

import java.awt.Color;
import static javax.swing.WindowConstants.*;

import java.awt.Dimension;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.BorderFactory;
import javax.swing.GroupLayout;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.SwingUtilities;

/**
 * <p>
 * タイトル: さきゅばす
 * </p>
 *
 * <p>
 * 説明: ニコニコ動画の動画をコメントつきで保存
 * </p>
 *
 * <p>
 * 著作権: Copyright (c) 2007 PSI
 * </p>
 *
 * <p>
 * 会社名:
 * </p>
 *
 * @author 未入力
 * @version 1.0
 */
public class MainFrame_AboutBox extends JDialog implements ActionListener {

    private static final String VERSION = "いんきゅばす 2.0.0";
    private static final long serialVersionUID = -4256413309312729840L;
    private static final Logger logger = Logger.getLogger(MainFrame_AboutBox.class.getName());
    private static final String LINE_FEED = System.getProperty("line.separator");
    private final JButton okButton = new JButton();

    public MainFrame_AboutBox(Frame parent) {
        super(parent);
        try {
            setDefaultCloseOperation(DISPOSE_ON_CLOSE);
            jbInit();
        } catch (Exception exception) {
            logger.log(Level.SEVERE, null, exception);
        }
    }

    public MainFrame_AboutBox() {
        this(null);
    }

    /**
     * コンポーネントの初期化。
     *
     * @throws java.lang.Exception
     */
    private void jbInit() {
        final JPanel basePanel = new JPanel();

        final JLabel imageLabel = new JLabel();
        final ImageIcon icon = new ImageIcon(saccubus.MainFrame_AboutBox.class.getResource("icon.png"));
        imageLabel.setIcon(icon);

        final JTextArea productField = createProductField();
        productField.setOpaque(false);
        productField.setBorder(BorderFactory.createEmptyBorder());
        productField.setBackground(new Color(0, 0, 0, 0));

        final JScrollPane licensePane = createLicensePane();

        okButton.setText("OK");
        okButton.addActionListener(this);


        basePanel.setPreferredSize(new Dimension(500, 600));
        GroupLayout gl = new GroupLayout(basePanel);
        basePanel.setLayout(gl);

        gl.setHorizontalGroup(gl.createParallelGroup(GroupLayout.Alignment.CENTER)
                .addGroup(gl.createSequentialGroup()
                    .addGap(15).addComponent(imageLabel).addGap(30).addComponent(productField).addGap(30))
                .addComponent(licensePane)
                .addComponent(okButton));

        gl.setVerticalGroup(gl.createSequentialGroup()
                .addGap(15)
                .addGroup(gl.createParallelGroup()
                    .addComponent(imageLabel).addComponent(productField))
                .addGap(15)
                .addComponent(licensePane)
                .addComponent(okButton));

        getContentPane().add(basePanel, null);

        setTitle("バージョン情報");
        setResizable(true);
    }

    private JTextArea createProductField() {
        final JTextArea area = new JTextArea();
        area.append(VERSION);
        area.append(LINE_FEED);
        area.append(LINE_FEED);

        try (BufferedReader reader = new BufferedReader(new InputStreamReader(getClass().getResourceAsStream(
                        "saccubus_description.txt"), "UTF-8"))) {
            String line;
            while ((line = reader.readLine()) != null) {
                area.append(line);
                area.append(LINE_FEED);
            }
        } catch (IOException ex) {
            logger.log(Level.SEVERE, null, ex);
        }

        area.setEditable(false);
        return area;
    }

    private JScrollPane createLicensePane() {
        final JTextArea licenseField = new JTextArea();
        try (BufferedReader reader = new BufferedReader(new InputStreamReader(getClass().getResourceAsStream(
                        "LICENSE.txt"), "UTF-8"))) {
            String line;
            while ((line = reader.readLine()) != null) {
                licenseField.append(line);
                licenseField.append(LINE_FEED);
            }
        } catch (IOException ex) {
            logger.log(Level.SEVERE, null, ex);
        }

        licenseField.setCaretPosition(0);
        licenseField.setEditable(false);
        final JScrollPane licensePane = new JScrollPane(licenseField);
        return licensePane;
    }

    /**
     * ボタンイベントでダイアログを閉じる
     *
     * @param actionEvent
     *            ActionEvent
     */
    @Override
    public void actionPerformed(ActionEvent actionEvent) {
        if (actionEvent.getSource() == okButton) {
            dispose();
        }
    }

    public static void main(String[] args) {
        SwingUtilities.invokeLater(new Runnable() {

            @Override
            public void run() {
                MainFrame_AboutBox frame = new MainFrame_AboutBox();
                frame.pack();
                frame.setVisible(true);
            }
        });
    }
}
